@@ -173,34 +173,56 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
     }
 
     @Override
-    public void deleteAccount(Session session, int accountId) throws OXException {
+    public OAuthAccount getAccount(int contextId, int userId, int accountId) throws OXException {
+        Context context = getContext(contextId);
+        Connection connection = getConnection(true, context);
+        try {
+            return getAccount(contextId, userId, accountId, connection);
+        } catch (SQLException e) {
+            throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+        } finally {
+            provider.releaseReadConnection(context, connection);
+        }
+    }
+
+    @Override
+    public boolean deleteAccount(Session session, int accountId) throws OXException {
         int userId = session.getUserId();
         int contextId = session.getContextId();
-        final Context context = getContext(contextId);
-        final Connection con = getConnection(false, context);
+
+        Connection connection = (Connection) session.getParameter("__file.storage.delete.connection");
+        if (connection != null) {
+            try {
+                if (Databases.isInTransaction(connection)) {
+                    // Given connection is already in transaction. Invoke & return immediately.
+                    return deleteAccount(session, accountId, connection);
+                }
+            } catch (SQLException e) {
+                throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            }
+        }
+
+        Context context = getContext(contextId);
+        connection = getConnection(false, context);
         int rollback = 0;
-        PreparedStatement stmt = null;
         try {
-            startTransaction(con);
+            startTransaction(connection);
             rollback = 1;
 
             final DeleteListenerRegistry deleteListenerRegistry = DeleteListenerRegistry.getInstance();
             final Map<String, Object> properties = new HashMap<>(2);
-            // Hint to not update the scopes since it's an oauth account deletion
+            // Hint to not update the scopes since it's an OAuth account deletion
             // This hint has to be passed via the delete listener
             properties.put(OAuthConstants.SESSION_PARAM_UPDATE_SCOPES, Boolean.FALSE);
 
-            deleteListenerRegistry.triggerOnBeforeDeletion(accountId, properties, userId, contextId, con);
-            stmt = con.prepareStatement("DELETE FROM oauthAccounts WHERE cid = ? AND user = ? and id = ?");
-            stmt.setInt(1, contextId);
-            stmt.setInt(2, userId);
-            stmt.setInt(3, accountId);
-            stmt.executeUpdate();
-            deleteListenerRegistry.triggerOnAfterDeletion(accountId, properties, userId, contextId, con);
+            deleteListenerRegistry.triggerOnBeforeDeletion(accountId, properties, userId, contextId, connection);
+            boolean deleted = deleteAccount(session, accountId, connection);
+            deleteListenerRegistry.triggerOnAfterDeletion(accountId, properties, userId, contextId, connection);
 
-            con.commit(); // COMMIT
+            connection.commit(); // COMMIT
             rollback = 2;
             LOG.info("Deleted OAuth account with id '{}' for user '{}' in context '{}'", I(accountId), I(userId), I(contextId));
+            return deleted;
         } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } catch (OXException e) {
@@ -208,14 +230,13 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         } catch (RuntimeException e) {
             throw OAuthExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } finally {
-            Databases.closeSQLStuff(stmt);
             if (rollback > 0) {
                 if (rollback == 1) {
-                    Databases.rollback(con);
+                    Databases.rollback(connection);
                 }
-                Databases.autocommit(con);
+                Databases.autocommit(connection);
             }
-            provider.releaseReadConnection(context, con);
+            provider.releaseReadConnection(context, connection);
         }
     }
 
@@ -735,6 +756,19 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
 
     ////////////////////////////////////// HELPERS //////////////////////////////////////////
 
+    protected boolean deleteAccount(Session session, int accountId, Connection connection) throws SQLException {
+        PreparedStatement stmt = null;
+        try {
+            stmt = connection.prepareStatement("DELETE FROM oauthAccounts WHERE cid = ? AND user = ? and id = ?");
+            stmt.setInt(1, session.getContextId());
+            stmt.setInt(2, session.getUserId());
+            stmt.setInt(3, accountId);
+            return stmt.executeUpdate() > 0;
+        } finally {
+            Databases.closeSQLStuff(stmt);
+        }
+    }
+
     /**
      *
      * @param session
@@ -851,6 +885,35 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
+    private OAuthAccount getAccount(int contextId, int userId, int accountId, Connection connection) throws SQLException, OXException {
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        try {
+            stmt = connection.prepareStatement("SELECT displayName, serviceId, scope FROM oauthAccounts WHERE cid = ? AND user = ? and id = ?");
+            stmt.setInt(1, contextId);
+            stmt.setInt(2, userId);
+            stmt.setInt(3, accountId);
+            rs = stmt.executeQuery();
+            if (!rs.next()) {
+                throw OAuthExceptionCodes.ACCOUNT_NOT_FOUND.create(Integer.valueOf(accountId), Integer.valueOf(userId), Integer.valueOf(contextId));
+            }
+
+            DefaultOAuthAccount account = new DefaultOAuthAccount();
+            account.setId(accountId);
+            String displayName = rs.getString(1);
+            account.setDisplayName(displayName);
+
+            account.setMetaData(registry.getService(rs.getString(2), userId, contextId));
+            String scopes = rs.getString(3);
+            OAuthScopeRegistry scopeRegistry = Services.getService(OAuthScopeRegistry.class);
+            Set<OAuthScope> enabledScopes = scopeRegistry.getAvailableScopes(account.getMetaData().getAPI(), OXScope.valuesOf(scopes));
+            account.setEnabledScopes(enabledScopes);
+            return account;
+        } finally {
+            closeSQLStuff(rs, stmt);
+        }
+    }
+
     /**
      *
      * @param session
@@ -904,7 +967,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      * @return The {@link Context}
      * @throws OXException if the {@link Context} cannot be retrieved
      */
-    private Context getContext(final int contextId) throws OXException {
+    Context getContext(final int contextId) throws OXException {
         try {
             return contextService.getContext(contextId);
         } catch (OXException e) {
@@ -912,6 +975,26 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
+    /**
+     * Releases specified read-only connection.
+     *
+     * @param ctx The associated context
+     * @param con The connection to release
+     */
+    void releaseReadConnection(Context context, Connection connection) {
+        provider.releaseReadConnection(context, connection);
+    }
+
+    /**
+     * Releases specified read-write connection.
+     *
+     * @param ctx The associated context
+     * @param con The connection to release
+     */
+    void releaseWriteConnection(Context context, Connection connection) {
+        provider.releaseWriteConnection(context, connection);
+    }
+
     /**
      * Retrieves a {@link ConnectException} from the {@link DBProvider}
      *
@@ -920,7 +1003,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      * @return The {@link Connection}
      * @throws OXException if the {@link Connection} cannot be retrieved
      */
-    private Connection getConnection(final boolean readOnly, final Context context) throws OXException {
+    Connection getConnection(final boolean readOnly, final Context context) throws OXException {
         return readOnly ? provider.getReadConnection(context) : provider.getWriteConnection(context);
     }
 
