@@ -90,9 +90,9 @@ public final class OAuthDeleteListener implements DeleteListener {
                 stmt.setInt(pos++, contextId);
                 stmt.setInt(pos++, userId);
                 stmt.executeUpdate();
-            } catch (final SQLException e) {
+            } catch (SQLException e) {
                 throw DeleteFailedExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-            } catch (final Exception e) {
+            } catch (Exception e) {
                 throw DeleteFailedExceptionCodes.ERROR.create(e, e.getMessage());
             } finally {
                 Databases.closeSQLStuff(stmt);
@@ -111,9 +111,9 @@ public final class OAuthDeleteListener implements DeleteListener {
                 int pos = 1;
                 stmt.setInt(pos++, contextId);
                 stmt.executeUpdate();
-            } catch (final SQLException e) {
+            } catch (SQLException e) {
                 throw DeleteFailedExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-            } catch (final Exception e) {
+            } catch (Exception e) {
                 throw DeleteFailedExceptionCodes.ERROR.create(e, e.getMessage());
             } finally {
                 Databases.closeSQLStuff(stmt);
