@@ -95,6 +95,11 @@ public final class OSGiContextService extends AbstractOSGiDelegateService<Contex
         return getService().getSchemaAssociationsFor(contextIds);
     }
 
+    @Override
+    public boolean exists(int contextId) throws OXException {
+        return getService().exists(contextId);
+    }
+
     @Override
     public Context getContext(int contextId) throws OXException {
         return getService().getContext(contextId);
