@@ -294,7 +294,7 @@ public final class InitAction extends AbstractOAuthTokenAction {
     private String urlEncode(final String s) {
         try {
             return URLEncoder.encode(s, "ISO-8859-1");
-        } catch (final UnsupportedEncodingException e) {
+        } catch (UnsupportedEncodingException e) {
             return s;
         }
     }
