@@ -55,6 +55,7 @@ import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
+import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.oauth.OAuthAccountDeleteListener;
@@ -113,7 +114,7 @@ public class YahooOAuthActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, OAuthService.class, DeferringURLService.class, ThreadPoolService.class, OAuthScopeRegistry.class, OAuthAccessRegistryService.class, SSLSocketFactoryProvider.class };
+        return new Class<?>[] { ConfigurationService.class, OAuthService.class, DeferringURLService.class, ThreadPoolService.class, OAuthScopeRegistry.class, OAuthAccessRegistryService.class, SSLSocketFactoryProvider.class, DispatcherPrefixService.class };
     }
 
     @Override
