@@ -92,7 +92,7 @@ public final class XingEventHandler implements EventHandler {
                     }
                 }
             }
-        } catch (final Exception e) {
+        } catch (Exception e) {
             LOG.error("Error while handling SessionD event \"{}\".", topic, e);
         }
     }
