@@ -49,6 +49,7 @@
 
 package com.openexchange.xing.access.osgi;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.util.Dictionary;
 import java.util.Hashtable;
 import org.osgi.framework.ServiceRegistration;
@@ -82,7 +83,7 @@ import com.openexchange.xing.access.internal.XingOAuthAccessImpl;
  */
 public final class XingOAuthAccessActivator extends HousekeepingActivator {
 
-    private volatile ServiceRegistration<XingOAuthAccessProvider> providerRegistration;
+    private ServiceRegistration<XingOAuthAccessProvider> providerRegistration;
 
     /**
      * Initializes a new {@link XingOAuthAccessActivator}.
@@ -120,7 +121,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
     /**
      * Registers the provider.
      */
-    public void registerProvider() {
+    public synchronized void registerProvider() {
         final XingOAuthAccessProvider provider = new XingOAuthAccessProvider() {
 
             @Override
@@ -129,7 +130,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
                 final OAuthAccount oAuthAccount = oAuthService.getAccount(session, oauthAccountId);
 
                 OAuthAccessRegistryService registryService = Services.getService(OAuthAccessRegistryService.class);
-                OAuthAccessRegistry registry = registryService.get(KnownApi.XING.getFullName());
+                OAuthAccessRegistry registry = registryService.get(KnownApi.XING.getServiceId());
                 OAuthAccess oAuthAccess = registry.get(session.getContextId(), session.getUserId(), oAuthAccount.getId());
                 if (oAuthAccess == null) {
                     // Create
@@ -150,7 +151,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
                     return oAuthService.getDefaultAccount(KnownApi.XING, session).getId();
                 } catch (OXException e) {
                     if (OAuthExceptionCodes.ACCOUNT_NOT_FOUND.equals(e)) {
-                        throw XingExceptionCodes.NO_OAUTH_ACCOUNT.create(e, session.getUserId(), session.getContextId());
+                        throw XingExceptionCodes.NO_OAUTH_ACCOUNT.create(e, I(session.getUserId()), I(session.getContextId()));
                     }
                     throw e;
                 }
@@ -167,7 +168,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
     /**
      * Unregisters the provider.
      */
-    public void unregisterProvider() {
+    public synchronized void unregisterProvider() {
         final ServiceRegistration<XingOAuthAccessProvider> providerRegistration = this.providerRegistration;
         if (null != providerRegistration) {
             providerRegistration.unregister();
